Enum stream_httparse::header::HeaderKey[][src]

pub enum HeaderKey<'a> {
    StrRef(&'a str),
    Str(String),
}
Allows the HeaderKey to take the form of a variety of different valid Types, mostly related to their lifetimes. This however also gives more control over how they are compared to each other, ignoring case in this case

use stream_httparse::header::HeaderKey;

assert_eq!(HeaderKey::StrRef("TeSt"), HeaderKey::StrRef("test"));

Variants

StrRef(&'a str)

Tuple Fields

0: &'a str

Stores the Key as a refernce to a String

Str(String)

Tuple Fields

0: String

Stores the Key as an owned String

Implementations

Serializes the Key into the Buffer by appending the Data to it

Clones all the needed Data in order to create a new HeaderKey that is completly independant of the given self reference