Enum stream_httparse::header::HeaderKey [−][src]
Allows the HeaderKey to take the form of a variety of different valid Types, mostly related to their lifetimes. This however also gives more control over how they are compared to each other, ignoring case in this case
use stream_httparse::header::HeaderKey;
assert_eq!(HeaderKey::StrRef("TeSt"), HeaderKey::StrRef("test"));Variants
StrRef(&'a str)
Tuple Fields
0: &'a strStores the Key as a refernce to a String
Str(String)
Tuple Fields
0: StringStores the Key as an owned String
Implementations
Serializes the Key into the Buffer by appending the Data to it