Enum stream_httparse::header::HeaderValue [−][src]
A single HeaderValue that can hold Data in a variety of forms allowing for easier and more flexible use
Variants
StrRef(&'a str)
Tuple Fields
0: &'a strStores the Value as a reference to a String
Str(String)
Tuple Fields
0: StringStores the Value as an owned String
NumberUsize(usize)
Tuple Fields
0: usizeStores the Value in its raw Number format
Implementations
Serializes the Value into the given Buffer by appending the Data to it
Turns the given Value, regardless of how it is stored, into an owned String
Compares the Two values without case
Any number type in either of them immediately returns false
Tries to return a reference to the underlying String, if it is a String, otherwise returns None
Clones all the needed Data in order to create a new HeaderValue that is completly independant of the given self reference